@@ -15,6 +15,7 @@
 #include <qslider.h>
 #include <qlayout.h>
 #include <qcolor.h>
+#include <qcolormap.h>
 #include <qlabel.h>
 
 #include <kapplication.h>
@@ -34,7 +35,7 @@ class KLorenzSaverInterface : public KScreenSaverInterface
 
 public:
     virtual KAboutData* aboutData() {
-        return new KAboutData( "klorenz.kss", 0, ki18n( "KLorenz" ), "2.2.0", ki18n( "KLorenz" ) );
+        return new KAboutData( "klorenz.kss", "klock", ki18n( "KLorenz" ), "2.2.0", ki18n( "KLorenz" ) );
     }
 
 
@@ -90,14 +91,19 @@ KLorenzSetup::KLorenzSetup( QWidget *parent )
     QWidget *main = new QWidget(this);
 	setMainWidget(main);
 
-    QHBoxLayout *tl = new QHBoxLayout( main, 0, spacingHint() );
+    QHBoxLayout *tl = new QHBoxLayout( main );
+    tl->setSpacing( spacingHint() );
     QVBoxLayout *tl1 = new QVBoxLayout;
     tl->addLayout(tl1);
 
     QLabel *label = new QLabel( i18n("Speed:"), main );
     tl1->addWidget(label);
 
-    sps = new QSlider(MINSPEED, MAXSPEED, 10, speed, Qt::Horizontal, main);
+    sps = new QSlider(Qt::Horizontal, main);
+    sps->setMinimum(MINSPEED);
+    sps->setMaximum(MAXSPEED);
+    sps->setPageStep(10);
+    sps->setValue(speed);
     sps->setMinimumSize( 120, 20 );
     sps->setTickPosition(QSlider::TicksBelow);
     sps->setTickInterval(150);
@@ -107,7 +113,11 @@ KLorenzSetup::KLorenzSetup( QWidget *parent )
     label = new QLabel( i18n("Epoch:"), main );
     tl1->addWidget(label);
 
-    eps = new QSlider(MINEPOCH, MAXEPOCH, 100, epoch, Qt::Horizontal, main);
+    eps = new QSlider(Qt::Horizontal, main);
+    eps->setMinimum(MINEPOCH);
+    eps->setMaximum(MAXEPOCH);
+    eps->setPageStep(100);
+    eps->setValue(epoch);
     eps->setMinimumSize( 120, 20 );
     eps->setTickPosition(QSlider::TicksBelow);
     eps->setTickInterval(3000);
@@ -117,7 +127,11 @@ KLorenzSetup::KLorenzSetup( QWidget *parent )
     label = new QLabel( i18n("Color rate:"), main );
     tl1->addWidget(label);
 
-    crs = new QSlider(MINCOLOR, MAXCOLOR, 5, crate, Qt::Horizontal, main);
+    crs = new QSlider(Qt::Horizontal, main);
+    crs->setMinimum(MINCOLOR);
+    crs->setMaximum(MAXCOLOR);
+    crs->setPageStep(5);
+    crs->setValue(crate);
     crs->setMinimumSize( 120, 20 );
     crs->setTickPosition(QSlider::TicksBelow);
     crs->setTickInterval(10);
@@ -127,7 +141,11 @@ KLorenzSetup::KLorenzSetup( QWidget *parent )
     label = new QLabel( i18n("Rotation Z:"), main );
     tl1->addWidget(label);
 
-    zrs = new QSlider(MINZROT, MAXZROT, 18, zrot, Qt::Horizontal, main);
+    zrs = new QSlider(Qt::Horizontal, main);
+    zrs->setMinimum(MINZROT);
+    zrs->setMaximum(MAXZROT);
+    zrs->setPageStep(18);
+    zrs->setValue(zrot);
     zrs->setMinimumSize( 120, 20 );
     zrs->setTickPosition(QSlider::TicksBelow);
     zrs->setTickInterval(36);
@@ -137,7 +155,11 @@ KLorenzSetup::KLorenzSetup( QWidget *parent )
     label = new QLabel( i18n("Rotation Y:"), main );
     tl1->addWidget(label);
 
-    yrs = new QSlider(MINYROT, MAXYROT, 18, yrot, Qt::Horizontal, main);
+    yrs = new QSlider(Qt::Horizontal, main);
+    yrs->setMinimum(MINYROT);
+    yrs->setMaximum(MAXYROT);
+    yrs->setPageStep(18);
+    yrs->setValue(yrot);
     yrs->setMinimumSize( 120, 20 );
     yrs->setTickPosition(QSlider::TicksBelow);
     yrs->setTickInterval(36);
@@ -147,7 +169,11 @@ KLorenzSetup::KLorenzSetup( QWidget *parent )
     label = new QLabel( i18n("Rotation X:"), main );
     tl1->addWidget(label);
 
-    xrs = new QSlider(MINXROT, MAXXROT, 18, xrot, Qt::Horizontal, main);
+    xrs = new QSlider(Qt::Horizontal, main);
+    xrs->setMinimum(MINXROT);
+    xrs->setMaximum(MAXXROT);
+    xrs->setPageStep(18);
+    xrs->setValue(xrot);
     xrs->setMinimumSize( 120, 20 );
     xrs->setTickPosition(QSlider::TicksBelow);
     xrs->setTickInterval(36);
@@ -156,7 +182,12 @@ KLorenzSetup::KLorenzSetup( QWidget *parent )
 
     preview = new QWidget( main );
     preview->setFixedSize( 220, 165 );
-    preview->setBackgroundColor( Qt::black );
+    {
+        QPalette palette;
+        palette.setColor( preview->backgroundRole(), Qt::black );
+        preview->setPalette( palette );
+	preview->setAutoFillBackground(true);
+    }
     preview->show();    // otherwise saver does not get correct size
     saver = new KLorenzSaver( preview->winId() );
     tl->addWidget(preview);
@@ -457,11 +488,12 @@ KLorenzSaver::KLorenzSaver( WId id ) : KScreenSaver( id )
     mat = new Matrix3D();
     updateMatrix();
 
-    setBackgroundColor( Qt::black );
     newEpoch();
 
     timer.start( 10 );
     connect( &timer, SIGNAL( timeout() ), SLOT( update() ) );
+    setAttribute( Qt::WA_NoSystemBackground );
+    show();
 }
 
 KLorenzSaver::~KLorenzSaver()
@@ -552,16 +584,15 @@ static void lorenz(double x, double y, double z, double& dx, double& dy, double&
 // No need to go beyond 2nd order for a screensaver!
 void KLorenzSaver::paintEvent(QPaintEvent *)
 {
-    setAttribute( Qt::WA_NoSystemBackground ); // Only after initial clear
-
     double kx, ky, kz, dx, dy, dz;
     const double h = 0.0001;
     const double tqh = h * 3.0 / 4.0;
     QPainter p(this);
 
     if ( !e )
-        erase();
+        p.fillRect(rect(), Qt::black);
 
+    QColormap cmap = QColormap::instance();
     for (int i=0; i<speed; i++) {
         // Runge-Kutta formula
         lorenz(x,y,z,dx,dy,dz);
@@ -573,9 +604,9 @@ void KLorenzSaver::paintEvent(QPaintEvent *)
         mat->transform(x,y,z,kx,ky,kz);
         // Choose a color
         p.setPen(
-            QColor((int)(sin(t*crate/pi)*127+128),
-                   (int)(sin(t*crate/(pi-1))*127+128),
-                   (int)(sin(t*crate/(pi-2))*127+128)).pixel() );
+            cmap.pixel(QColor((int)(sin(t*crate/pi)*127+128),
+                              (int)(sin(t*crate/(pi-1))*127+128),
+                              (int)(sin(t*crate/(pi-2))*127+128))) );
         // Draw a point
         p.drawPoint( (int)(kx*width()*1.5/kz)+(int)(width()/2),
                      (int)(ky*height()*1.5/kz)+(int)(height()/2));
