@@ -581,7 +581,7 @@ void KScienceSaver::readSettings()
 	for(int i=0; i < MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		group = KGlobal::config()->group( "Mode" + sMode );
+		group = KGlobal::config()->group( QLatin1String( "Mode" ) + sMode );
 		moveX[i]     = group.readEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
 		moveY[i]     = group.readEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
 		size[i]      = group.readEntry(  "Size",      SCI_DEFAULT_SIZE);
@@ -663,7 +663,7 @@ void KScienceSaver::slotTimeout()
 		myAssert( height() - diam > 0, "assertion violated: height-diam > 0" );
 		y = (double) (height() - diam - 1);
 	}
-	
+
 	xcoord = (int) x ;
 	ycoord = (int) y ;
 	signed int dx = (signed int) xcoord - oldx;
@@ -869,7 +869,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	showButtonSeparator(true);
 	readSettings();
 	initModeInfo();
-
+       setButtonText( Help, i18n( "A&bout" ) );
 	QWidget *main = new QWidget(this);
 	setMainWidget(main);
 
@@ -1005,7 +1005,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	// preview
 	preview = new KPreviewWidget( main );
 	preview->setFixedSize( 220, 170 );
-	QPixmap p( KStandardDirs::locate("data", "kscreensaver/pics/kscience.png") );
+	QPixmap p( KStandardDirs::locate("data", QLatin1String( "kscreensaver/pics/kscience.png" )) );
 	QPalette palette;
 	if( p.isNull() ) {
 		palette.setColor( preview->backgroundRole(), Qt::black );
@@ -1056,7 +1056,7 @@ void KScienceSetup::readSettings()
 	for(int i=0; i < MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		group = KGlobal::config()->group( "Mode" + sMode );
+		group = KGlobal::config()->group( QLatin1String( "Mode" ) + sMode );
 		moveX[i]     = group.readEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
 		moveY[i]     = group.readEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
 		size[i]      = group.readEntry(  "Size",      SCI_DEFAULT_SIZE);
@@ -1165,7 +1165,7 @@ void KScienceSetup::slotOk()
 	for(int i=0; i<MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		group = KGlobal::config()->group("Mode" + sMode );
+		group = KGlobal::config()->group(QLatin1String( "Mode" ) + sMode );
 		group.writeEntry( "MoveX",     moveX[i]     );
 		group.writeEntry( "MoveY",     moveY[i]     );
 		group.writeEntry( "Size",      size[i]      );
