@@ -59,8 +59,8 @@ KXSRangeControl::KXSRangeControl(QWidget *parent, const QString &name,
 {
 	// NOTE: Contexts used and assembled here have to match with contexts
 	// extracted by the PO template creation script.
-	
-    if (attr.value("type") == "spinbutton" ) {
+
+    if (attr.value(QLatin1String( "type" )) == QLatin1String( "spinbutton" ) ) {
 	QHBoxLayout *hb = new QHBoxLayout(this);
 	if (!mLabel.isEmpty()) {
 	    QLabel *l = new QLabel(i18nc("@label:spinbox", mLabel.toUtf8()), this);
@@ -74,8 +74,8 @@ KXSRangeControl::KXSRangeControl(QWidget *parent, const QString &name,
 	connect(mSpinBox, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
 	hb->addWidget(mSpinBox);
     } else {
-	QString lowLabel = attr.value("_low-label");
-	QString highLabel = attr.value("_high-label");
+	QString lowLabel = attr.value(QLatin1String( "_low-label" ));
+	QString highLabel = attr.value(QLatin1String( "_high-label" ));
 	QVBoxLayout *vb = new QVBoxLayout(this);
 	if (!mLabel.isEmpty()) {
 	    QLabel *l = new QLabel(i18nc("@label:slider", mLabel.toUtf8()), this);
@@ -83,8 +83,8 @@ KXSRangeControl::KXSRangeControl(QWidget *parent, const QString &name,
 	}
 	QHBoxLayout *hb = new QHBoxLayout();
         vb->addLayout(hb);
-	QString limCtxt = mLabel.isEmpty() ? QString("@item:inrange")
-	                                   : QString("@item:inrange %1").arg(mLabel);
+	QString limCtxt = mLabel.isEmpty() ? QLatin1String("@item:inrange")
+	                                   : QString(QLatin1String( "@item:inrange %1" )).arg(mLabel);
 	if (!lowLabel.isEmpty()) {
 	    QLabel *l = new QLabel(i18nc(limCtxt.toUtf8(), lowLabel.toUtf8()), this);
 	    hb->addWidget(l);
@@ -145,8 +145,8 @@ KXSDoubleRangeControl::KXSDoubleRangeControl(QWidget *parent,
     // NOTE: Contexts used and assembled here have to match with contexts
     // extracted by the PO template creation script.
 
-    QString lowLabel = attr.value("_low-label");
-    QString highLabel = attr.value("_high-label");
+    QString lowLabel = attr.value(QLatin1String( "_low-label" ));
+    QString highLabel = attr.value(QLatin1String( "_high-label" ));
     QVBoxLayout *vb = new QVBoxLayout(this);
     if (!mLabel.isEmpty()) {
 	QLabel *l = new QLabel(i18nc("@label:slider", mLabel.toUtf8()), this);
@@ -154,8 +154,8 @@ KXSDoubleRangeControl::KXSDoubleRangeControl(QWidget *parent,
     }
     QHBoxLayout *hb = new QHBoxLayout();
     vb->addLayout(hb);
-    QString limCtxt = !mLabel.isEmpty() ? QString("@item:inrange %1").arg(mLabel)
-                                        : QString("@item:inrange");
+    QString limCtxt = !mLabel.isEmpty() ? QString(QLatin1String( "@item:inrange %1" )).arg(mLabel)
+                                        : QLatin1String("@item:inrange");
     if (!lowLabel.isEmpty()) {
 	QLabel *l = new QLabel(i18nc(limCtxt.toUtf8(), lowLabel.toUtf8()), this);
 	hb->addWidget(l);
@@ -257,8 +257,8 @@ void KXSDropListControl::addOption(const QXmlAttributes &attr)
     // NOTE: Contexts used and assembled here have to match with contexts
     // extracted by the PO template creation script.
 
-    QString itemCtxt = mLabel.isEmpty() ? QString("@option:radio")
-                                        : QString("@option:radio %1").arg(mLabel);
+    QString itemCtxt = mLabel.isEmpty() ? QLatin1String("@option:radio")
+                                        : QString(QLatin1String( "@option:radio %1" )).arg(mLabel);
     KXSSelectItem::addOption( attr );
     mCombo->addItem( i18nc(itemCtxt.toUtf8(), mOptions[mOptions.count()-1].toUtf8()) );
     if ( mValue == mOptions.count()-1 )
@@ -345,7 +345,7 @@ KXSFileControl::KXSFileControl(QWidget *parent, const QString &name,
   mEdit = new QLineEdit(this);
   connect(mEdit, SIGNAL(textChanged(const QString &)), SLOT(textChanged(const QString &)));
   hb->addWidget(mEdit);
-  QPushButton *pb = new QPushButton( "...", this );
+  QPushButton *pb = new QPushButton( QLatin1String( "..." ), this );
   connect( pb, SIGNAL(clicked()), this, SLOT(selectFile()) );
   hb->addWidget(pb);
 }
